summaryrefslogtreecommitdiff
path: root/src/mongo/db/pipeline/expression_context.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/pipeline/expression_context.h')
-rw-r--r--src/mongo/db/pipeline/expression_context.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/db/pipeline/expression_context.h b/src/mongo/db/pipeline/expression_context.h
index d483834be18..8e2be4cdb2b 100644
--- a/src/mongo/db/pipeline/expression_context.h
+++ b/src/mongo/db/pipeline/expression_context.h
@@ -56,7 +56,7 @@
namespace mongo {
-class AggregateCommand;
+class AggregateCommandRequest;
class ExpressionContext : public RefCountable {
public:
@@ -104,7 +104,7 @@ public:
* 'resolvedNamespaces' maps collection names (not full namespaces) to ResolvedNamespaces.
*/
ExpressionContext(OperationContext* opCtx,
- const AggregateCommand& request,
+ const AggregateCommandRequest& request,
std::unique_ptr<CollatorInterface> collator,
std::shared_ptr<MongoProcessInterface> mongoProcessInterface,
StringMap<ExpressionContext::ResolvedNamespace> resolvedNamespaces,
@@ -113,7 +113,7 @@ public:
/**
* Constructs an ExpressionContext to be used for Pipeline parsing and evaluation. This version
* requires finer-grained parameters but does not require an AggregateCommand.
* 'resolvedNamespaces' maps collection names (not full namespaces) to ResolvedNamespaces.
*/
ExpressionContext(OperationContext* opCtx,
@@ -113,7 +113,7 @@ public:
/**
* Constructs an ExpressionContext to be used for Pipeline parsing and evaluation. This version
- * requires finer-grained parameters but does not require an AggregateCommand.
+ * requires finer-grained parameters but does not require an AggregateCommandRequest.
* 'resolvedNamespaces' maps collection names (not full namespaces) to ResolvedNamespaces.
*/